Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Program ¶
type Program struct {
// contains filtered or unexported fields
}
Program represents a program that can be Run.
func (Program) Run ¶
Run runs the program, sending its STDOUT and STDERR to the given writers, and kills it if the context is done before the program has finished.
type Template ¶
type Template struct {
// contains filtered or unexported fields
}
Template represents a program, as a list of strings with at least the program's path as the first argument, plus any arguments. The program's path and arguments can be text templates.
func (*Template) Execute ¶
Execute executes each of the template args with the given vars, and return a Program.
Source Files
¶
- program.go
Click to show internal directories.
Click to hide internal directories.